**gotchas in these tests**

These tests may have warnings to do with type checking. This is frustrating because the types are all good - the issue
 lies with the nested approach to the tests. Type checking tools don't seem to enjoy the inner defined annotated
 functions.
